@@ -16,7 +16,7 @@
  *            Editorwindows.py
  *
  *  Thu Apr  8 15:08:38 2004
- *  Copyright  2004  Stas Z
+ *  Copyright  2005  Stas Z
  *  stasz@linux.isbeter.nl
  ****************************************************************************/
 These are the new editor window objects for gvr. 
@@ -359,7 +359,7 @@ class EditorWindow(wxFrame):
             self,
             L2U(_("Choose a filename for your program")),
             os.path.dirname(self.filePath),
-            os.path.basename(self.filePath+self.ext),
+            os.path.basename(self.filePath.split(self.ext)[0]+self.ext),
             self.wxext,
             wxSAVE | wxOVERWRITE_PROMPT)
         if dlg.ShowModal() == wxID_OK:
@@ -402,7 +402,6 @@ class WorldEditorWindow(EditorWindow):
         self.kwords = [L2U(_('ROBOT')).title(), L2U(_('WALL')).title(),\
                     L2U(_('BEEPERS')).title(), L2U(_('SIZE')).title()]
         #self.kwords = [L2U(_('Robot')), L2U(_('Wall')), L2U(_('Beepers')), L2U(_('Size'))]
-        print "kwords",self.kwords
         EditorWindow.__init__(self,gui)
         file = wxMenu()
         file.Append(ID_LOADWORLD, L2U(_("&Open World for Editing...")),\
@@ -441,7 +440,6 @@ class CodeEditorWindow(EditorWindow):
         
         #self.kwords = gvrparser.TESTS+gvrparser.COMMANDS+gvrparser.DIV
         self.kwords = gvrparser.lookup_dict.keys()
-        print "kwords from parser\n ",self.kwords
         EditorWindow.__init__(self,gui)
         file = wxMenu()
         file.Append(ID_LOADCODE, L2U(_("&Open Program for Editing...")),\
