@@ -106,9 +106,15 @@ New instructions can be created for Guido van Robot using the define statement.
 define <new_name>:
     <instruction>
 """
-def set_summary(lang):
+def set_summary(olang):
     """Get the proper summary file for the current locale"""
     global OnRefText
+    # Quick hack to fix the loading of Summary.txt, should be done trying all
+    # components of the locale, probably removing the -LANG suffix, as the
+    # language is already on the locale dir and putting it in two places makes
+    # things harder; is best to use the directory to choose the language or
+    # put all the Summaries on the same dir.
+    lang = olang.split('@')[0].split('.')[0].split('_')[0]
     sumfile = "Summary-%s.txt" % lang
     if lang == 'en':
         path = os.path.join(get_rootdir(),'po',sumfile)
@@ -119,7 +125,7 @@ def set_summary(lang):
         lines = open(path,'r').read()
     except IOError,info:
         print info
-        print "Can't load %s",path
+        print "Can't load Summary for language '%s'" % lang
         print "Using default English file"
         OnRefText = BuiltinOnRefText
     else:
