@@ -5,22 +5,37 @@ wxPython GUI for GvR
 see ABOUT_TEXT in version.py for more info
 '''
 import sys
+
 OrgSysPath = sys.path[0]# wxCrapware changes the sys.path !!
+
+import wxversion
+WXVERSION = None
+try:
+    wxversion.select("2.4")
+    WXVERSION="2.4"
+except wxversion.VersionError:
+    pass
 try:
-    import wxversion     # if multiple versions are installed
     wxversion.select("2.5")
-except Exception, info:
-    print info
-    print "Can not import wxversion and/or select version 2.5"
-    print "Will attempt to import existing version of wxPython."
+    WXVERSION="2.5"
+except wxversion.VersionError:
+    pass
+try:
+    wxversion.select("2.6")
+    WXVERSION="2.6"
+except wxversion.VersionError:
+    pass
+if WXVERSION not in ("2.6","2.5","2.4"):
+    txt = "Failed to import wxPython 2.4|2.5|2.6\nMake sure you have wxPython properly installed"
+    print txt
+    sys.exit(1)
+
 import wx
-
 from wxPython.wx import *
-#wxlocale = wx.Locale(wx.LANGUAGE_DEFAULT)
-
 from wxPython.lib.dialogs import wxScrolledMessageDialog
 
 sys.path[0] = OrgSysPath # reset path to original
+
 from utils import *
 from version import ABOUT_TEXT
 import ConfigParser,os,shutil
@@ -60,6 +75,9 @@ def SetLocale(lang=None):
         
 SetLocale()
 
+# This sets WXVERSION as a global in utils.py so that other modules can access it
+set_wxversion(WXVERSION)
+
 import Text
 Text.set_summary(LocaleMesg[1])# needed to set summary file used to the current locale
 
