@@ -4,6 +4,8 @@
     Author: Andre Roberge    Copyright  2005
     andre.roberge@gmail.com
 
+    Adapted for gvr by Stas Zytkiewicz. stas@linux.isbeter.nl
+    
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -29,17 +31,8 @@
     that show some possible uses.
     """
 import rur_misc
-if rur_misc.WX_VERSION == 0:
-    try:
-        import wxversion     # if multiple versions are installed
-        wxversion.select("2.5")
-        rur_misc.WX_VERSION = 2.5
-    except Exception, info:
-        print info
-        print "Can not import wxversion in WorldCreation.py "
-        print "Will attempt to import existing version of wxPython."
-        #most likely only version 2.4 (or earlier) installed
-        rur_misc.WX_VERSION = 2 # placeholder for some other version
+from utils import WXVERSION
+rur_misc.WX_VERSION = WXVERSION
 
 import wx
 from wxPython.wx import *
