@@ -4,6 +4,9 @@
     Version 0.7
     Author: Andre Roberge    Copyright  2005
     andre.roberge@gmail.com
+    
+    Adapted for gvr by Stas Zytkiewicz. stas@linux.isbeter.nl
+    
 """
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,17 +23,8 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 import rur_misc
-if rur_misc.WX_VERSION == 0:
-    try:
-        import wxversion     # if multiple versions are installed
-        wxversion.select("2.5")
-        rur_misc.WX_VERSION = 2.5
-    except Exception, info:
-        print info
-        print "Can not import wxversion in WorldDisplay.py "
-        print "Will attempt to import existing version of wxPython."
-        #most likely only version 2.4 (or earlier) installed
-        rur_misc.WX_VERSION = 2 # placeholder for some other version
+from utils import WXVERSION
+rur_misc.WX_VERSION = WXVERSION
 
 import wx
 from wxPython.wx import *
@@ -46,10 +40,12 @@ import rur_dialogs
 
 class WorldGUI(wxScrolledWindow):
     def __init__(self, parent, id = -1, size = wxDefaultSize):
-        wxScrolledWindow.__init__(self, parent, id, (0, 0), size=size,
-                                  style=wxSUNKEN_BORDER)
-        self.SetBackgroundColour("WHITE")
         self.world = Visible_world()
+        wxScrolledWindow.__init__(self, parent, id, (0, 0),
+                                size=(self.world.maxWidth+8, self.world.maxHeight+8),
+                                style=wxSUNKEN_BORDER)
+        self.SetBackgroundColour("WHITE")
+        
         self.editor = False  #
         self.InitialiseVariables()
         self.MakePopupMenu()
@@ -67,15 +63,15 @@ class WorldGUI(wxScrolledWindow):
         # Set the size of the total window, of which only a small part
         # will be displayed; apparently SetVirtualSize needs
         # a single (tuple) argument, which explains the double (( )).
-        self.SetVirtualSize((self.world.maxWidth, self.world.maxHeight))
+        #self.SetVirtualSize((self.world.maxWidth, self.world.maxHeight))
 
         # Set the scrolling rate; use same value in both horizontal and
         # vertical directions.
         scrollRate = self.world.tile_narrow + self.world.tile_wide
         self.SetScrollRate(scrollRate, scrollRate)
-        # yPos below set so that we are at the bottom of the scrolledWindow
+
         self.SetScrollbars(1, 1, self.world.maxWidth,
-                           self.world.maxHeight, yPos=self.world.maxHeight)
+                           self.world.maxHeight)
         # allow for testing "new and improved" robot
         self.newRobot = False
 
@@ -410,138 +406,6 @@ class AddBeeperPopup(MyPopupWindow):
         self.Show(False)
         self.Destroy()
 
-## DEAD CODE !
-##class ResizeWorldPopup(MyPopupWindow):
-##    """Allows user to resize world, within limited range."""
-##    def __init__(self, parent):
-##        mesg = "Select the desired world dimensions (streets and avenues).\n"\
-##               "The existing walls and beepers will be removed."
-##        MyPopupWindow.__init__(self, parent, mesg, 380, 360)
-##        try:
-##            edit_world_image = wxImage(os.path.join('bitmaps','edit_world.png'),
-##                                        wxBITMAP_TYPE_PNG).ConvertToBitmap()
-##        except Exception,info:
-##            print __name__, info
-##            print "Problem loading edit_world.png in WorldDisplay.py"
-##
-##        self.world = parent.world
-##        self.robot = parent.world.robot_dict
-##        self.parent = parent
-##        min_avenues = 7
-##        min_streets = 7
-##        max_avenues = 30
-##        max_streets = 30
-##        self.streets = parent.world.st
-##        self.avenues = parent.world.av
-##
-##
-##        if rur_misc.WX_VERSION == 2.5:
-##            self.slider_street = wxSlider(
-##                # id, value, min, max, (x, y), (length, height)
-##                self, -1, self.streets, min_streets, max_streets,
-##                (40, 70), (-1, -1), # can not get it to stretch vertically :-(
-##                wxSL_VERTICAL | wxSL_AUTOTICKS | wxSL_LABELS
-##                )
-##        else:
-##            self.slider_street = wxSlider(
-##                # id, value, min, max, (x, y), (length, height)
-##                self, -1, self.streets, min_streets, max_streets,
-##                (40, 70), (-1, 320),
-##                wxSL_VERTICAL | wxSL_AUTOTICKS | wxSL_LABELS
-##                )
-##
-##        self.slider_street.SetTickFreq(1, 1)
-##        self.slider_avenue = wxSlider(
-##            # id, value, min, max, (x, y), (length, height)
-##            self, -1, self.avenues, min_avenues, max_avenues,
-##            (60, 50), (300, -1),
-##            wxSL_HORIZONTAL | wxSL_AUTOTICKS | wxSL_LABELS
-##            )
-##        self.slider_avenue.SetTickFreq(1, 1)
-##        #
-##        wxStaticBitmap(self, -1, edit_world_image, (110, 90))
-##        b = wxButton(self, -1, "Ok", (150, 320))
-##        if rur_misc.WX_VERSION == 2.5:
-##            self.Bind(wx.EVT_BUTTON, self.OnOK, b)
-##        else:
-##            EVT_BUTTON(self, -1, self.OnOK)
-##        wxCallAfter(self.Refresh)
-##
-##    def OnOK(self, evt):
-##        st = self.slider_street.GetValue()
-##        av = self.slider_avenue.GetValue()
-##
-##        self.world.resetDimensions(av, st)
-##        if 'robot' in self.robot:
-##            self.robot['robot']._setPos(1, 1) # brings robot back to the origin
-##            self.robot['robot']._facing = 3   # facing east
-##            self.robot['robot'].robot_image = \
-##                     self.robot['robot']._image[self.robot['robot']._facing]
-##        # prepare to recreate the background images
-##        self.world.background_images_created = False
-##        self.world.AdjustWorldSize()
-##        self.world.InitTileSizes()
-##        self.parent.InitialiseVariables()
-##        self.world.DoDrawing()
-##        # create a new bitmap image
-##        self.parent.buffer = wxEmptyBitmap(self.world.maxWidth,
-##                                           self.world.maxHeight)
-##        self.parent.drawImage()
-##
-##        self.Show(False)
-##        self.Destroy()
-##
-### Note: the following is NOT tested within this file; it would make
-### little sense.
-##class SetDelayPopup(MyPopupWindow):
-##    """Allows user to set a time delay between robot movements."""
-##    def __init__(self, parent):
-##        self.parent = parent
-##
-##        mesg = "Select the desired robot speed"
-##        # here speed is somewhat inversely related to the time delay
-##        MyPopupWindow.__init__(self, parent, mesg, 450, 200, colour="white")
-##
-##        try:
-##            snail_img = wxImage('snail.png',
-##                                wxBITMAP_TYPE_PNG).ConvertToBitmap()
-##        except Exception,info:
-##            print __name__, info
-##            print "Problem loading snail.png in WorldDisplay.py"
-##
-##        try:
-##            cheetah_img = wxImage('cheetah.png',
-##                                  wxBITMAP_TYPE_PNG).ConvertToBitmap()
-##        except Exception,info:
-##            print __name__, info
-##            print "Problem loading cheetah.png in WorldDisplay.py"
-##
-##        self.min_speed = 1
-##        self.max_speed = 100
-##
-##        actual_delay = self.parent.world.robot_dict['robot'].delay
-##        default_speed = int(1.0/actual_delay)
-##        self.slider_speed = wxSlider(
-##            # id, value, min, max, (x, y), (length, height)
-##            self, -1, default_speed, self.min_speed, self.max_speed,
-##            (100, 80), (200, -1),
-##            wxSL_HORIZONTAL | wxSL_AUTOTICKS | wxSL_LABELS
-##            )
-##        self.slider_speed.SetTickFreq(10, 1)
-##
-##        wxStaticBitmap(self, -1, snail_img, (10, 50))
-##        wxStaticBitmap(self, -1, cheetah_img, (320, 50))
-##        b = wxButton(self, -1, "Ok", (200, 150))
-##        EVT_BUTTON(self, -1, self.OnOK)
-##        wxCallAfter(self.Refresh)
-##
-##    def OnOK(self, evt):
-##        speed = self.slider_speed.GetValue()
-##        self.parent.world.robot_dict['robot'].delay = 1./speed
-##        self.Show(False)
-##        self.Destroy()
-
-
 #--- Self-testing part (visual testing)-------
 class RURworldParent(wxFrame):
     def __init__(self, parent):
@@ -551,10 +415,4 @@ class RURworldParent(wxFrame):
         gui.world.DoDrawing() # redraw to include robot on canvas
         gui.drawImage()   # redraw to include robot on buffer
 
-##if __name__ == '__main__':
-##    rur_dialogs.rurMessageDialog(rur_translatable.USE_MAIN_APP, "!")
-##    frame = RURworldParent(None)
-##    frame.Show(True)
-##    app.MainLoop()
-
 
