@@ -25,13 +25,19 @@ import os,sys,traceback,gettext,locale,__builtin__,shutil,types
 # a world file from the editor window.
 NULL_WORLD = 'Robot 1 1 N 0'
 # will hold the locale set by set_locale()
-
 LANG_TRANS = ''
+# Will hold the wxPython version number. It is set by set_wxversion()
+WXVERSION=''
+
 def get_rootdir():
     """Returns the CWD of GvR, on Linux this will be the same as os.getcwd().
      But on win32, it can be anything when run from a standalone exe, crapware!"""
     return os.path.abspath(sys.path[0])
 
+def set_wxversion(version):
+    global WXVERSION
+    WXVERSION = version
+
 # Base path for the gettext mo files
 if os.name == 'nt':
     LOCALEDIR = os.path.join(get_rootdir(),'locale')
@@ -47,7 +53,16 @@ def get_locale():
     """Get the systems locale.
     This can be different from the locale used by gvr.(see set_locale())"""
     try:
-        lang = locale.getdefaultlocale()[0].split("_")[0]
+        lang = ''
+        # FIX locale.py LANGUAGE parsing bug, the fix was added on the
+        # upstream CVS on the 1.28.4.2 revision of 'locale.py', It
+        # should be included on Python 2.4.2.
+        if os.environ.has_key('LANGUAGE'):
+            lang = os.environ['LANGUAGE'].split(':')[0]
+        # This makes sure that we never return a value of None.
+        # This is a fix for systems that set LANGUAGE to ''.
+        if lang == '':
+            lang = locale.getdefaultlocale()[0]
     except Exception,info:
         print >> sys.stderr,info
         print "Switching to English"
@@ -70,13 +85,18 @@ def set_locale(lang=None):
         if lang == 'en': 
             __builtin__.__dict__['_'] = lambda x:x
             return ("","en")
+        languages = [ lang ]
+        if os.environ.has_key('LANGUAGE'):
+            languages += os.environ['LANGUAGE'].split(':')
         lang_trans = gettext.translation('gvr',\
                                      localedir=LOCALEDIR,\
-                                     languages=[lang])
+                                     languages=languages)
         __builtin__.__dict__['_'] = lang_trans.ugettext
     except Exception,info:
-        txt = "Cannot set language to %s \n switching to English" % lang
-        print >> sys.stderr,info,txt
+        txt=""
+        if lang.split('@')[0].split('.')[0].split('_')[0] != 'en':
+            txt = "Cannot set language to '%s' \n switching to English" % lang
+            print >> sys.stderr,info,txt
         __builtin__.__dict__['_'] = lambda x:x
         return (txt,"en")
     LANG_TRANS = lang_trans
